Utility
=======

.. currentmodule:: graspologic.utils

Transformations
---------------

.. autofunction:: pass_to_ranks

.. autofunction:: to_laplacian

.. autofunction:: augment_diagonal

.. autofunction:: symmetrize

.. autofunction:: remove_loops

Connected Components
--------------------

.. autofunction:: is_fully_connected

.. autofunction:: largest_connected_component

.. autofunction:: multigraph_lcc_union

.. autofunction:: multigraph_lcc_intersection

IO
--

.. autofunction:: import_graph

.. autofunction:: import_edgelist

Other
-----

.. autofunction:: remap_labels